@@ -168,57 +168,42 @@ void CDesktop::drawStatus(QPainter *p, QRectF rect, bool status)
 
 void CDesktop::drawDesktop(QPainter *p)
 {
-    QMatrix mp3Matrix = renderer->matrixForElement("MP3_STATUS");
-    mp3Matrix = mp3Matrix.scale(1.245, 1.329);
     QRectF mp3Status = renderer->boundsOnElement("MP3_STATUS");
     if ( state)
-    	drawStatus(p, mp3Matrix.mapRect(mp3Status) , CMafwMeta::self().getEnable() );
-    
+    	drawStatus(p, mp3Status , CMafwMeta::self().getEnable() );
 
-    QMatrix rtcomMatrix = renderer->matrixForElement("RTCOM_STATUS");
-    rtcomMatrix = rtcomMatrix.scale(1.245, 1.338);
     QRectF rtcomStatus = renderer->boundsOnElement("RTCOM_STATUS");
     if ( state)
-    	drawStatus(p, rtcomMatrix.mapRect(rtcomStatus) , CRTCom::self().getEnable() );
+    	drawStatus(p, rtcomStatus , CRTCom::self().getEnable() );
     
-    QMatrix smsMatrix = renderer->matrixForElement("SMS_STATUS");
-    smsMatrix = smsMatrix.scale(1.248, 1.344);
     QRectF smsStatus = renderer->boundsOnElement("SMS_STATUS");
     if ( state)
-        drawStatus(p, smsMatrix.mapRect(smsStatus) , false );
+        drawStatus(p, smsStatus , false );
 
     QFont localFont = p->font();
     localFont.setPointSize(14);
     p->setFont(localFont);
     p->setPen(Qt::white);
 
-    mp3Matrix = renderer->matrixForElement("MP3");
-    mp3Matrix = mp3Matrix.scale(1.245, 1.329);
     QRectF mp3Rect = renderer->boundsOnElement("MP3");
-    p->drawText(mp3Matrix.mapRect(mp3Rect) , Qt::AlignLeft, tr("Musics tags") ); 
+    p->drawText(mp3Rect , Qt::AlignLeft, tr("Musics tags") ); 
     
-    rtcomMatrix = renderer->matrixForElement("RTCOM");
-    rtcomMatrix = rtcomMatrix.scale(1.245, 1.338);
     QRectF rtcomRect = renderer->boundsOnElement("RTCOM");
-    p->drawText(rtcomMatrix.mapRect(rtcomRect) , Qt::AlignLeft, tr("Call Status") ); 
+    p->drawText(rtcomRect , Qt::AlignLeft, tr("Call Status") ); 
     
-    smsMatrix = renderer->matrixForElement("SMS");
-    smsMatrix = smsMatrix.scale(1.245, 1.344);
     QRectF smsRect = renderer->boundsOnElement("SMS");
-    p->drawText(smsMatrix.mapRect(smsRect), Qt::AlignLeft, tr("SMS Message") ); 
+    p->drawText(smsRect, Qt::AlignLeft, tr("SMS Message") ); 
 
     localFont = p->font();
     localFont.setPointSize(16);
     localFont.setBold(true);
     p->setFont(localFont);
     
-    QMatrix titleMatrix = renderer->matrixForElement("TITLE");
-    titleMatrix = titleMatrix.scale(1.245, 1.296);
     QRectF titleRect = renderer->boundsOnElement("TITLE");
     if ( state)
-    	p->drawText(titleMatrix.mapRect(titleRect) , Qt::AlignLeft, CRdsBroadcast::self().getDefText() ); 
+    	p->drawText(titleRect , Qt::AlignLeft, CRdsBroadcast::self().getDefText() ); 
     else
-    	p->drawText(titleMatrix.mapRect(titleRect) , Qt::AlignLeft, tr("Transmiter off") ); 
+    	p->drawText(titleRect , Qt::AlignLeft, tr("Transmiter off") ); 
 }
 
 void CDesktop::slotFMTXChanged(QString type, QString status)
