@@ -26,8 +26,8 @@ CRdsBroadcast * CRdsBroadcast::m_self = 0;
 CRdsBroadcast::CRdsBroadcast(QObject * parent)
 : QObject(parent)
 ,refresh(5000)
-,display(9)
-,withDBus(false)
+,display(8)
+,withDBus(true)
 ,endTime(30000)
 ,defText("RDS Linux")
 {
@@ -55,7 +55,11 @@ CRdsBroadcast::~CRdsBroadcast()
 {
    QSettings cfg;
    cfg.setValue("broadcast/refresh", refresh);
-   cfg.setValue("broadcast/display", display);
+   if (!withDBus) {
+   	cfg.setValue("broadcast/display", display);
+   } else {
+   	cfg.setValue("broadcast/display", 8 );
+   }
    cfg.setValue("broadcast/withDBus", withDBus);
    cfg.setValue("broadcast/defaultText", defText);
 
@@ -65,7 +69,7 @@ void CRdsBroadcast::slotSetText(QString text, int timeout)
 {
      endTime = timeout;
      if (withDBus) {
-	     setDBusText(text);
+	     setDBusText(text.leftJustified(8,' ',true) );
      } else {
 	     // Cut text into parts depending of length
 	     // and call every delay to display each part
@@ -146,7 +150,7 @@ void CRdsBroadcast::slotUpdateText()
     textCount++;
 }
 
-void CRdsBroadcast::setDBusText(QString &text)
+void CRdsBroadcast::setDBusText(QString text)
 {
      QDBusMessage message = QDBusMessage::createMethodCall ( "com.nokia.FMTx", 
 			"/com/nokia/fmtx/default", // FM TX dbus path 
@@ -155,7 +159,7 @@ void CRdsBroadcast::setDBusText(QString &text)
     QList<QVariant> list;
     list.append("com.nokia.FMTx.device");
     list.append("rds_ps");
-    list.append(QVariant::fromValue(QDBusVariant(text)) );
+    list.append(QVariant::fromValue(QDBusVariant(text) ) );
     message.setArguments(list);
 
     QDBusMessage reply = QDBusConnection::systemBus().call(message);
