@@ -6,3 +6,6 @@
 #define RTCOM_CSD_PATH  "/com/nokia/csd/call"
 #define RTCOM_CSD_IF   "com.nokia.csd.Call"
 #define RTCOM_CSD_INST_IF   "com.nokia.csd.Call.Instance"
+
+#define FMTX_PATH "/com/nokia/fmtx/default"
+#define FMTX_IF "com.nokia.policy"
